@@ -3,7 +3,7 @@ BEGIN {
   $Tapper::Benchmark::Query::SQLite::AUTHORITY = 'cpan:TAPPER';
 }
 # ABSTRACT: Tapper::Benchmark - qerying - SQLite backend
-$Tapper::Benchmark::Query::SQLite::VERSION = '0.003';
+$Tapper::Benchmark::Query::SQLite::VERSION = '0.004';
 use strict;
 use warnings;
 use feature 'switch';
@@ -586,6 +586,19 @@ sub select_benchmark {
 
 }
 
+sub select_benchmark_names {
+
+    my ( $or_self, @a_vals ) = @_;
+
+    my $query = "
+        SELECT DISTINCT bench
+        FROM $or_self->{config}{tables}{benchmark_table}";
+    $query .= "
+        WHERE bench LIKE ? " if @a_vals;
+    return $or_self->execute_query( $query, @a_vals );
+
+}
+
 sub select_unit {
 
     my ( $or_self, @a_vals ) = @_;
